@@ -3,7 +3,7 @@
 /*
     This file is part of Magnum.
 
-    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019
               Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
@@ -26,7 +26,7 @@
 */
 
 /** @file
- * @brief Forward declarations for the @ref Magnum namespace
+ * @brief Forward declarations and basic types for the @ref Magnum namespace
  */
 
 #include <Corrade/Utility/Utility.h>
@@ -34,31 +34,8 @@
 #include "Magnum/Types.h"
 #include "Magnum/Math/Math.h"
 
-#ifdef MAGNUM_BUILD_DEPRECATED
-#include <Corrade/Utility/Macros.h>
-#endif
-
-#ifndef DOXYGEN_GENERATING_OUTPUT
-typedef unsigned int GLenum; /* Needed for *Format and *Type enums */
-#endif
-
 namespace Magnum {
 
-namespace Math {
-    #ifndef DOXYGEN_GENERATING_OUTPUT
-    template<class> struct Constants;
-
-    #ifdef MAGNUM_BUILD_DEPRECATED
-    namespace Literals {
-        constexpr Rad<Double> operator "" _rad(long double);
-        constexpr Deg<Double> operator "" _deg(long double);
-        constexpr Rad<Float> operator "" _radf(long double);
-        constexpr Deg<Float> operator "" _degf(long double);
-    }
-    #endif
-    #endif
-}
-
 /* Bring whole Corrade namespace */
 using namespace Corrade;
 
@@ -89,15 +66,25 @@ Defined if built as static libraries. Default are shared libraries.
 #define MAGNUM_BUILD_STATIC
 #undef MAGNUM_BUILD_STATIC
 
-/**
-@brief Multi-threaded build
-
-Defined if the library is built in a way that allows multiple thread-local
-Magnum contexts. Enabled by default.
-@see @ref building, @ref cmake, @ref Magnum::Context::current() "Context::current()"
-*/
+#ifdef MAGNUM_BUILD_DEPRECATED
+/** @brief Multi-threaded build
+ * @deprecated Use @ref CORRADE_BUILD_MULTITHREADED instead.
+ */
 #define MAGNUM_BUILD_MULTITHREADED
 #undef MAGNUM_BUILD_MULTITHREADED
+#endif
+
+/**
+@brief OpenGL interoperability
+
+Defined if the engine is built with OpenGL interoperability enabled --- extra
+APIs in various libraries interacting with the @ref Magnum::GL "GL" library.
+Enabled by default in case the @ref Magnum::GL "GL" library is built.
+@see @ref MAGNUM_TARGET_GLES2, @ref MAGNUM_TARGET_GLES3,
+    @ref MAGNUM_TARGET_DESKTOP_GLES, @ref building, @ref cmake
+*/
+#define MAGNUM_TARGET_GL
+/* (enabled by default) */
 
 /**
 @brief OpenGL ES target
@@ -168,6 +155,17 @@ for more information.
 */
 #define MAGNUM_TARGET_HEADLESS
 #undef MAGNUM_TARGET_HEADLESS
+
+/**
+@brief Vulkan interoperability
+
+Defined if the engine is built with Vulkan interoperability enabled --- extra
+APIs in various libraries interacting with the @ref Magnum::Vk "Vk" library.
+Enabled by default in case the @ref Magnum::Vk "Vk" library is built.
+@see @ref building, @ref cmake
+*/
+#define MAGNUM_TARGET_VK
+#undef MAGNUM_TARGET_VK
 #endif
 
 /** @{ @name Basic type definitions
@@ -203,21 +201,11 @@ Equivalent to GLSL @glsl int @ce.
 */
 typedef std::int32_t Int;
 
-#ifndef MAGNUM_TARGET_WEBGL
-/**
-@brief Unsigned long (64bit)
-
-@requires_gles 64-bit integers are not available in WebGL.
-*/
+/** @brief Unsigned long (64bit) */
 typedef std::uint64_t UnsignedLong;
 
-/**
-@brief Signed long (64bit)
-
-@requires_gles 64-bit integers are not available in WebGL.
-*/
+/** @brief Signed long (64bit) */
 typedef std::int64_t Long;
-#endif
 
 /**
 @brief Float (32bit)
@@ -230,6 +218,30 @@ typedef float Float;
 /** @brief Half (16bit) */
 typedef Math::Half Half;
 
+/**
+@brief Two-component bool vector
+
+Equivalent to GLSL @glsl bvec2 @ce.
+@m_keyword{bvec2,GLSL bvec2,}
+*/
+typedef Math::BoolVector<2> BoolVector2;
+
+/**
+@brief Three-component bool vector
+
+Equivalent to GLSL @glsl bvec3 @ce.
+@m_keyword{bvec3,GLSL bvec3,}
+*/
+typedef Math::BoolVector<3> BoolVector3;
+
+/**
+@brief Four-component bool vector
+
+Equivalent to GLSL @glsl bvec4 @ce.
+@m_keyword{bvec4,GLSL bvec4,}
+*/
+typedef Math::BoolVector<4> BoolVector4;
+
 /**
 @brief Two-component float vector
 
@@ -308,6 +320,9 @@ typedef Math::Color3<Float> Color3;
 /** @brief Four-component (RGBA) float color */
 typedef Math::Color4<Float> Color4;
 
+/** @brief HSV float color */
+typedef Math::ColorHsv<Float> ColorHsv;
+
 /**
 @brief Three-component (RGB) unsigned byte color
 
@@ -432,6 +447,21 @@ typedef Math::CubicBezier2D<Float> CubicBezier2D;
 /** @brief Float three-dimensional cubic Bézier curve */
 typedef Math::CubicBezier3D<Float> CubicBezier3D;
 
+/** @brief Float scalar cubic Hermite spline point */
+typedef Math::CubicHermite1D<Float> CubicHermite1D;
+
+/** @brief Float two-dimensional cubic Hermite spline point */
+typedef Math::CubicHermite2D<Float> CubicHermite2D;
+
+/** @brief Float three-dimensional cubic Hermite spline point */
+typedef Math::CubicHermite3D<Float> CubicHermite3D;
+
+/** @brief Float cubic Hermite spline complex number */
+typedef Math::CubicHermiteComplex<Float> CubicHermiteComplex;
+
+/** @brief Float cubic Hermite spline quaternion */
+typedef Math::CubicHermiteQuaternion<Float> CubicHermiteQuaternion;
+
 /** @brief Float complex number */
 typedef Math::Complex<Float> Complex;
 
@@ -453,22 +483,22 @@ typedef Math::Deg<Float> Deg;
 /** @brief Angle in float radians */
 typedef Math::Rad<Float> Rad;
 
-/** @brief Float 1D range */
+/** @brief One-dimensional float range */
 typedef Math::Range1D<Float> Range1D;
 
-/** @brief Float 2D range */
+/** @brief Two-dimensional float range */
 typedef Math::Range2D<Float> Range2D;
 
-/** @brief Float 3D range */
+/** @brief Three-dimensional float range */
 typedef Math::Range3D<Float> Range3D;
 
-/** @brief Signed integer 1D range */
+/** @brief One-dimensional signed integer range */
 typedef Math::Range1D<Int> Range1Di;
 
-/** @brief Signed integer 2D range */
+/** @brief Two-dimensional signed integer range */
 typedef Math::Range2D<Int> Range2Di;
 
-/** @brief Signed integer 3D range */
+/** @brief Three-dimensional signed integer range */
 typedef Math::Range3D<Int> Range3Di;
 
 /** @brief Float frustum */
@@ -617,6 +647,21 @@ typedef Math::CubicBezier2D<Float> CubicBezier2Dd;
 /** @brief Double three-dimensional cubic Bézier curve */
 typedef Math::CubicBezier3D<Float> CubicBezier3Dd;
 
+/** @brief Double scalar cubic Hermite spline point */
+typedef Math::CubicHermite1D<Double> CubicHermite1Dd;
+
+/** @brief Double two-dimensional cubic Hermite spline point */
+typedef Math::CubicHermite2D<Double> CubicHermite2Dd;
+
+/** @brief Double three-dimensional cubic Hermite spline point */
+typedef Math::CubicHermite3D<Double> CubicHermite3Dd;
+
+/** @brief Double cubic Hermite spline complex number */
+typedef Math::CubicHermiteComplex<Double> CubicHermiteComplexd;
+
+/** @brief Double cubic Hermite spline quaternion */
+typedef Math::CubicHermiteQuaternion<Double> CubicHermiteQuaterniond;
+
 /** @brief Double complex number */
 typedef Math::Complex<Double> Complexd;
 
@@ -638,13 +683,13 @@ typedef Math::Deg<Double> Degd;
 /** @brief Angle in double radians */
 typedef Math::Rad<Double> Radd;
 
-/** @brief Double 1D range */
+/** @brief One-dimensional double range */
 typedef Math::Range1D<Double> Range1Dd;
 
-/** @brief Double 2D range */
+/** @brief Two-dimensional double range */
 typedef Math::Range2D<Double> Range2Dd;
 
-/** @brief Double 3D range */
+/** @brief Three-dimensional double range */
 typedef Math::Range3D<Double> Range3Dd;
 
 /** @brief Double frustum */
@@ -652,77 +697,13 @@ typedef Math::Frustum<Double> Frustumd;
 
 /*@}*/
 
-#ifdef MAGNUM_BUILD_DEPRECATED
-using Math::Literals::operator "" _deg;
-using Math::Literals::operator "" _rad;
-using Math::Literals::operator "" _degf;
-using Math::Literals::operator "" _radf;
-#endif
-
-/* Forward declarations for all types in root namespace */
-
 #ifndef DOXYGEN_GENERATING_OUTPUT
-/* FramebufferClear[Mask], FramebufferBlit[Mask], FramebufferBlitFilter,
-   FramebufferTarget enums used only directly with framebuffer instance */
-class AbstractFramebuffer;
-
-#if !(defined(MAGNUM_TARGET_WEBGL) && defined(MAGNUM_TARGET_GLES2))
-class AbstractQuery;
-#endif
-class AbstractShaderProgram;
-class AbstractTexture;
-
 template<UnsignedInt, class T> class Array;
 template<class T> class Array1D;
 template<class T> class Array2D;
 template<class T> class Array3D;
 
-template<UnsignedInt, class> class Attribute;
-
-enum class BufferUsage: GLenum;
-class Buffer;
-
-#ifndef MAGNUM_TARGET_GLES2
-template<UnsignedInt> class BufferImage;
-typedef BufferImage<1> BufferImage1D;
-typedef BufferImage<2> BufferImage2D;
-typedef BufferImage<3> BufferImage3D;
-
-template<UnsignedInt> class CompressedBufferImage;
-typedef CompressedBufferImage<1> CompressedBufferImage1D;
-typedef CompressedBufferImage<2> CompressedBufferImage2D;
-typedef CompressedBufferImage<3> CompressedBufferImage3D;
-#endif
-
-#if !defined(MAGNUM_TARGET_GLES2) && !defined(MAGNUM_TARGET_WEBGL)
-class BufferTexture;
-enum class BufferTextureFormat: GLenum;
-#endif
-
-#ifdef MAGNUM_BUILD_DEPRECATED
-template<class T> using BasicColor3 CORRADE_DEPRECATED_ALIAS("use Math::Color3 instead") = Math::Color3<T>;
-template<class T> using BasicColor4 CORRADE_DEPRECATED_ALIAS("use Math::Color4 instead") = Math::Color4<T>;
-#endif
-
-class Context;
-
-class CubeMapTexture;
-enum class CubeMapCoordinate: GLenum;
-#if !defined(MAGNUM_TARGET_GLES2) && !defined(MAGNUM_TARGET_WEBGL)
-class CubeMapTextureArray;
-#endif
-
-/* DebugOutput, DebugMessage, DebugGroup used only statically */
-/* DefaultFramebuffer is available only through global instance */
-/* DimensionTraits forward declaration is not needed */
-
-class Extension;
-class Framebuffer;
-
-#if !defined(MAGNUM_TARGET_GLES2) && !defined(MAGNUM_TARGET_WEBGL)
-enum class ImageFormat: GLenum;
-enum class ImageAccess: GLenum;
-#endif
+enum class InputFileCallbackPolicy: UnsignedByte;
 
 template<UnsignedInt> class Image;
 typedef Image<1> Image1D;
@@ -734,61 +715,34 @@ typedef CompressedImage<1> CompressedImage1D;
 typedef CompressedImage<2> CompressedImage2D;
 typedef CompressedImage<3> CompressedImage3D;
 
-template<UnsignedInt> class ImageView;
-typedef ImageView<1> ImageView1D;
-typedef ImageView<2> ImageView2D;
-typedef ImageView<3> ImageView3D;
+template<UnsignedInt, class> class ImageView;
+template<UnsignedInt dimensions> using BasicImageView = ImageView<dimensions, const char>;
+typedef BasicImageView<1> ImageView1D;
+typedef BasicImageView<2> ImageView2D;
+typedef BasicImageView<3> ImageView3D;
+template<UnsignedInt dimensions> using BasicMutableImageView = ImageView<dimensions, char>;
+typedef BasicMutableImageView<1> MutableImageView1D;
+typedef BasicMutableImageView<2> MutableImageView2D;
+typedef BasicMutableImageView<3> MutableImageView3D;
 
-#ifdef MAGNUM_BUILD_DEPRECATED
-template<UnsignedInt dimensions> using ImageReference CORRADE_DEPRECATED_ALIAS("use ImageView instead") = ImageView<dimensions>;
-typedef CORRADE_DEPRECATED("use ImageView1D instead") ImageView1D ImageReference1D;
-typedef CORRADE_DEPRECATED("use ImageView2D instead") ImageView2D ImageReference2D;
-typedef CORRADE_DEPRECATED("use ImageView3D instead") ImageView3D ImageReference3D;
-#endif
+template<UnsignedInt, class> class CompressedImageView;
+template<UnsignedInt dimensions> using BasicCompressedImageView = CompressedImageView<dimensions, const char>;
+typedef BasicCompressedImageView<1> CompressedImageView1D;
+typedef BasicCompressedImageView<2> CompressedImageView2D;
+typedef BasicCompressedImageView<3> CompressedImageView3D;
+template<UnsignedInt dimensions> using BasicMutableCompressedImageView = CompressedImageView<dimensions, char>;
+typedef BasicMutableCompressedImageView<1> MutableCompressedImageView1D;
+typedef BasicMutableCompressedImageView<2> MutableCompressedImageView2D;
+typedef BasicMutableCompressedImageView<3> MutableCompressedImageView3D;
 
-template<UnsignedInt> class CompressedImageView;
-typedef CompressedImageView<1> CompressedImageView1D;
-typedef CompressedImageView<2> CompressedImageView2D;
-typedef CompressedImageView<3> CompressedImageView3D;
+enum class MeshPrimitive: UnsignedInt;
+enum class MeshIndexType: UnsignedInt;
 
-enum class MeshPrimitive: GLenum;
-
-class Mesh;
-class MeshView;
-
-#if !defined(MAGNUM_TARGET_GLES2) && !defined(MAGNUM_TARGET_WEBGL)
-/* MultisampleTextureSampleLocations enum used only in the function */
-template<UnsignedInt> class MultisampleTexture;
-typedef MultisampleTexture<2> MultisampleTexture2D;
-typedef MultisampleTexture<3> MultisampleTexture2DArray;
-#endif
-
-enum class PixelFormat: GLenum;
-enum class PixelType: GLenum;
-enum class CompressedPixelFormat: GLenum;
-#ifdef MAGNUM_BUILD_DEPRECATED
-typedef CORRADE_DEPRECATED("use PixelFormat instead") PixelFormat ColorFormat;
-typedef CORRADE_DEPRECATED("use PixelType instead") PixelType ColorType;
-typedef CORRADE_DEPRECATED("use CompressedPixelFormat instead") CompressedPixelFormat CompressedColorFormat;
-#endif
+enum class PixelFormat: UnsignedInt;
+enum class CompressedPixelFormat: UnsignedInt;
 
 class PixelStorage;
-#ifndef MAGNUM_TARGET_GLES
 class CompressedPixelStorage;
-#endif
-
-/* ObjectFlag, ObjectFlags are used only in conjunction with *::wrap() function */
-
-class PrimitiveQuery;
-class SampleQuery;
-class TimeQuery;
-
-#ifndef MAGNUM_TARGET_GLES
-class RectangleTexture;
-#endif
-
-class Renderbuffer;
-enum class RenderbufferFormat: GLenum;
 
 enum class ResourceState: UnsignedByte;
 enum class ResourceDataState: UnsignedByte;
@@ -797,34 +751,11 @@ template<class T, class U = T> class Resource;
 class ResourceKey;
 template<class...> class ResourceManager;
 
-class Sampler;
-class Shader;
+enum class SamplerFilter: UnsignedInt;
+enum class SamplerMipmap: UnsignedInt;
+enum class SamplerWrapping: UnsignedInt;
 
-template<UnsignedInt> class Texture;
-#ifndef MAGNUM_TARGET_GLES
-typedef Texture<1> Texture1D;
-#endif
-typedef Texture<2> Texture2D;
-#if !(defined(MAGNUM_TARGET_WEBGL) && defined(MAGNUM_TARGET_GLES2))
-typedef Texture<3> Texture3D;
-#endif
-
-#ifndef MAGNUM_TARGET_GLES2
-template<UnsignedInt> class TextureArray;
-#ifndef MAGNUM_TARGET_GLES
-typedef TextureArray<1> Texture1DArray;
-#endif
-typedef TextureArray<2> Texture2DArray;
-#endif
-
-enum class TextureFormat: GLenum;
-
-#ifndef MAGNUM_TARGET_GLES2
-class TransformFeedback;
-#endif
 class Timeline;
-
-enum class Version: Int;
 #endif
 
 }
