@@ -3,7 +3,7 @@
 /*
     This file is part of Magnum.
 
-    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019
               Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
@@ -32,10 +32,6 @@
 #include "Magnum/Primitives/visibility.h"
 #include "Magnum/Trade/Trade.h"
 
-#ifdef MAGNUM_BUILD_DEPRECATED
-#include <Corrade/Utility/Macros.h>
-#endif
-
 namespace Magnum { namespace Primitives {
 
 /**
@@ -55,9 +51,9 @@ enum class SquareTextureCoords: UnsignedByte {
 
 2x2 square. Non-indexed @ref MeshPrimitive::TriangleStrip.
 
-@image html primitives-squaresolid.png
+@image html primitives-squaresolid.png width=256px
 
-@see @ref squareWireframe(), @ref planeSolid()
+@see @ref squareWireframe(), @ref planeSolid(), @ref gradient2D()
 */
 MAGNUM_PRIMITIVES_EXPORT Trade::MeshData2D squareSolid(SquareTextureCoords textureCoords = SquareTextureCoords::DontGenerate);
 
@@ -66,35 +62,12 @@ MAGNUM_PRIMITIVES_EXPORT Trade::MeshData2D squareSolid(SquareTextureCoords textu
 
 2x2 square. Non-indexed @ref MeshPrimitive::LineLoop.
 
-@image html primitives-squarewireframe.png
+@image html primitives-squarewireframe.png width=256px
 
 @see @ref squareSolid(), @ref planeWireframe()
 */
 MAGNUM_PRIMITIVES_EXPORT Trade::MeshData2D squareWireframe();
 
-#ifdef MAGNUM_BUILD_DEPRECATED
-/**
-@brief 2D square
-@deprecated Use @ref squareSolid() or @ref squareWireframe() instead.
-*/
-struct MAGNUM_PRIMITIVES_EXPORT Square {
-    /** @brief @copybrief SquareTextureCoords
-     * @deprecated Use @ref SquareTextureCoords instead.
-     */
-    typedef CORRADE_DEPRECATED("use SquareTextureCoords instead") SquareTextureCoords TextureCoords;
-
-    /** @brief @copybrief squareSolid()
-     * @deprecated Use @ref squareWireframe() instead.
-     */
-    CORRADE_DEPRECATED("use squareSolid() instead") static Trade::MeshData2D solid(SquareTextureCoords textureCoords = SquareTextureCoords::DontGenerate);
-
-    /** @brief @copybrief squareWireframe()
-     * @deprecated Use @ref squareWireframe() instead.
-     */
-    CORRADE_DEPRECATED("use squareWireframe() instead") static Trade::MeshData2D wireframe();
-};
-#endif
-
 }}
 
 #endif
